@@ -1,13 +1,15 @@
 from mc.JavaUtils import Random
 
 class Item:
-    TOTAL_STACK_SIZE = 99
+    TOTAL_STACK_SIZE = 100
     _rand = Random()
 
     def __init__(self, items, itemId):
         self.items = items
-        self.itemID = itemId
+        self.shiftedIndex = itemId + 256
+        items.itemsList[itemId + 256] = self
         self._maxStackSize = Item.TOTAL_STACK_SIZE
+        print(f'Setting items[{(itemId + 256)}] to {self}')
 
     def getIconIndex(self):
         return self.iconIndex
